import { NavLink } from 'react-router'
import checkSecondary from '~/images/check-secondary.png'
import Button from '../items/button'

interface Props {
  sections?: {
    icon: string
    title: string
    description: string
  }[]
  items: {
    imageUrl: string
    iconUrl?: string
    title: string
    description: string
    badge: {
      label: string
      type?: 'primary' | 'secondary'
    }
    list?: string[]
    url?: string
  }[]
}

export default function AppOddSection({ items, sections }: Props) {
  return (
    <div className="bg-[#F6F7F9] py-20 my-20">
      <div className="container mx-auto px-4 space-y-10 lg:space-y-32">
        {items.map((item, i) => (
          <div
            key={i}
            className="lg:flex space-y-4 sm:space-y-8 lg:space-y-0 even:flex-row-reverse items-center group"
          >
            <div className={`w-full lg:w-[45%] space-y-4 ${item.list ? '' : 'lg:space-y-8' } lg:group-even:pl-16 lg:group-odd:pr-16`}>
              <span
                className={`${item.badge.type === 'primary' ? 'text-primary bg-primary/20' : item.badge.type === 'secondary' ? 'bg-secondary/20 text-secondary' : 'bg-[#1E407A0D]'} inline-block rounded-full px-1 py-1 xl:px-3 xl:py-2 text-xs font-medium`}
              >
                {item.badge.label}
              </span>
              <h3
                className={`${item.iconUrl ? 'text-xl lg:text-2xl uppercase' : 'text-2xl lg:text-5xl'}  font-bold`}
              >
                {item.title}
              </h3>
              <p className="text-gray">{item.description}</p>
              {item.list && (
                <div className="space-y-2">
                  {item.list.map((listItem, i) => (
                    <div key={i} className="flex gap-2">
                      <span className="size-5 min-w-5 rounded-full border border-secondary bg-white shadow-md shadow-red-300 flex items-center justify-center mt-1">
                        <img src={checkSecondary} width={9} height={9} alt="" />
                      </span>
                      {listItem}
                    </div>
                  ))}
                </div>
              )}
              {item.url && (
                <NavLink to={item.url}>
                  <Button variant="secondary" className="py-4!">
                    Detayları Gör
                  </Button>
                </NavLink>
              )}
            </div>
            <div className="w-full lg:w-[55%] relative">
              {item.iconUrl && (
                <img
                  src={item.iconUrl}
                  className={`absolute 
                    group-odd:top-4
                    group-odd:right-4
                    lg:group-odd:top-8
                    lg:group-odd:right-8
                    group-even:bottom-4
                    group-even:left-4
                    lg:group-even:bottom-8
                    lg:group-even:left-8
                    h-1/3
                    lg:h-1/4`}
                  alt=""
                />
              )}
              <img
                src={item.imageUrl}
                className="w-full rounded-3xl border-8 border-white"
                alt=""
              />
            </div>
          </div>
        ))}
        {sections && (
          <div className="grid grid-cols-1 md:grid-cols-3 gap-4 lg:gap-8">
            {sections.map((section, i) => (
              <div
                key={i}
                className="bg-white rounded-xl border border-[#F4F4F5] p-2 lg:p-6 shadow text-center space-y-2 lg:space-y-6"
              >
                <div className="inline-flex size-14 bg-gray/10 shadow rounded-full items-center justify-center">
                  <img src={section.icon} width={28} height={28} alt="" />
                </div>
                <div className="space-y-2">
                  <h3 className="font-bold text-xl lg:text-3xl text-secondary">{section.title}</h3>
                  <p className="font-medium lg:text-lg">{section.description}</p>
                </div>
              </div>
            ))}
          </div>
        )}
      </div>
    </div>
  )
}
